import 'package:cresce_api/api.dart';
import 'package:test/test.dart';

import 'api_client_factory.dart';

void main() {
  group(EmployeesApi, () {
    test('getting employees returns employees', () async {
      var api = EmployeesApi();

      var result = await api.getEmployees(
        'myOrganization',
        user: await loginUser(),
      );

      expect(result, [
        EmployeeModel(
          id: 1,
          name: 'Ricardo Nunes',
          image: getImageSample(),
          title: 'Engineer',
          color: '0xFF2196F3',
          role: 'Admin',
        ),
        EmployeeModel(
          id: 2,
          name: 'Tester Employee',
          image: getImageSample(),
          title: 'Tester',
          color: '0xFF2196F3',
          role: 'Limited',
        ),
      ]);
    });

    test('validate employee credentials returns token', () async {
      var api = EmployeesApi();
      var pin = EmployeePin(employeeId: 1, pin: '1234');

      var result = await api.validatePin(
        pin,
        user: await loginUser(),
      ) as HttpBearerAuth;

      expect(result, isNotNull);
      expect(result.accessToken, isNotNull);
    });

    test('validate employee credentials throws ApiClientException', () async {
      var api = EmployeesApi();
      var pin = EmployeePin(employeeId: 1, pin: '12345');

      expect(
        () async => await api.validatePin(pin, user: await loginUser()),
        throwsA(TypeMatcher<ApiException>()),
      );
    });
  });
}
